# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [16.0.1.0.1] - 2025-07-15
### Changed
- [#151](https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/merge_requests/151) Update CHANGELOG

## [16.0.1.0.0] - 2025-03-07
- [#103](https://gitlab.com/somitcoop/erp-research/odoo-helpdesk/-/merge_requests/103) Migrate mail_activity_mail_template module to V16